# MQIT_DIA_ADFPRO
Anomaly Detection for Fast PROcesses (ADFPRO) is a Python application used to implement anomaly detection for "fast" processes that can be described by multiple features.
Fast means processes that are repeated continuously on manufacturing equipments and have a duration of a few seconds.

Repository includes 2 modules:
1) used from ML frameworks running on the cloud (Domino, SageMaker, AzureML) to trigger model training and classification on datasets having a certain structure;
2) used to implement Dash dashboards to visualize results

Uses code contained in MQIT_DIA_AIML_Toolkit.

Developed and maintained by MQ-IDS Data Integration and Analytics.
